<!DOCTYPE html>
<html lang="pt-BR">
<head>
  <meta charset="utf-8" />
  <meta name="viewport" content="width=device-width, initial-scale=1" />
  <meta name="robots" content="noindex, nofollow" />
  <title>Acesso · DNS Shield ISP</title>
  <link rel="stylesheet" href="{{ url_for('static', filename='css/app.css') }}" />
</head>
<body class="login-body">
  <main class="login-card">
    <div class="brand brand-center">
      <span class="brand-mark">DS</span>
      <div>
        <strong>DNS Shield ISP</strong>
        <small>Gestão de DNS recursivo e bloqueio judicial</small>
      </div>
    </div>

    {% if error %}<div class="flash flash-error">{{ error }}</div>{% endif %}

    <form method="post" autocomplete="off">
      <input type="hidden" name="csrf_token" value="{{ csrf_token() }}" />
      <label>Usuário
        <input type="text" name="username" required autofocus maxlength="64" />
      </label>
      <label>Senha
        <input type="password" name="password" required maxlength="128" />
      </label>
      <button class="btn btn-primary btn-block" type="submit">Entrar</button>
    </form>

    <p class="login-foot">v{{ app_version }} — {{ dev_name }} · {{ dev_email }}</p>
  </main>
</body>
</html>
