#!/usr/bin/env python3
"""DNS Shield ISP - entrada WSGI / desenvolvimento.

Desenvolvedor: Euquias Junior <junior@jbinfo.com.br>
"""
from dnsshield import create_app

app = create_app()

if __name__ == "__main__":
    app.run(host="0.0.0.0", port=8080, debug=False)
